@@ -198,6 +198,8 @@ int test_ctr()
 
 	assert(sizeof(m0) == 4 * 4 * 4);
 
+	glm::vec4 V{0, 1, 2, 3};
+
 	glm::mat4 m1{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15};
 
 	glm::mat4 m2{
@@ -206,10 +208,10 @@ int test_ctr()
 		{8, 9, 10, 11},
 		{12, 13, 14, 15}};
 
-	for(int i = 0; i < m0.length(); ++i)
+	for(glm::length_t i = 0; i < m0.length(); ++i)
 		Error += glm::all(glm::equal(m0[i], m2[i])) ? 0 : 1;
 
-	for(int i = 0; i < m1.length(); ++i)
+	for(glm::length_t i = 0; i < m1.length(); ++i)
 		Error += glm::all(glm::equal(m1[i], m2[i])) ? 0 : 1;
 
 	std::vector<glm::mat4> m3{
@@ -218,19 +220,9 @@ int test_ctr()
 		{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
 		{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}};
 
-/*
-	std::initializer_list<glm::mat4> m3{
-		{0, 1, 2, 3},
-		{4, 5, 6, 7},
-		{8, 9, 10, 11},
-		{12, 13, 14, 15}};
-*/
-	//glm::mat4 m4{m3};
-
 	std::vector<glm::mat4> v1{
 		{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
-		{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}
-	};
+		{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}};
 
 	std::vector<glm::mat4> v2{
 		{
@@ -244,8 +236,7 @@ int test_ctr()
 			{ 4, 5, 6, 7 },
 			{ 8, 9, 10, 11 },
 			{ 12, 13, 14, 15 }
-		}
-	};
+		}};
 
 #endif//GLM_HAS_INITIALIZER_LISTS
 
